package com.fs.hisStore.service;

import java.util.List;

import com.fs.his.vo.FsStoreOrderItemListDVO;
import com.fs.hisStore.domain.FsStoreOrderItemScrm;
import com.fs.hisStore.param.FsStoreOrderParam;
import com.fs.hisStore.vo.FsStoreOrderItemExportVO;
import com.fs.hisStore.vo.FsStoreOrderItemVO;

/**
 * 订单详情Service接口
 *
 * @author fs
 * @date 2022-03-21
 */
public interface IFsStoreOrderItemScrmService
{
    /**
     * 查询订单详情
     *
     * @param itemId 订单详情ID
     * @return 订单详情
     */
    public FsStoreOrderItemScrm selectFsStoreOrderItemById(Long itemId);

    /**
     * 查询订单详情列表
     *
     * @param fsStoreOrderItem 订单详情
     * @return 订单详情集合
     */
    public List<FsStoreOrderItemScrm> selectFsStoreOrderItemList(FsStoreOrderItemScrm fsStoreOrderItem);

    /**
     * 新增订单详情
     *
     * @param fsStoreOrderItem 订单详情
     * @return 结果
     */
    public int insertFsStoreOrderItem(FsStoreOrderItemScrm fsStoreOrderItem);

    /**
     * 修改订单详情
     *
     * @param fsStoreOrderItem 订单详情
     * @return 结果
     */
    public int updateFsStoreOrderItem(FsStoreOrderItemScrm fsStoreOrderItem);

    /**
     * 批量删除订单详情
     *
     * @param itemIds 需要删除的订单详情ID
     * @return 结果
     */
    public int deleteFsStoreOrderItemByIds(Long[] itemIds);

    /**
     * 删除订单详情信息
     *
     * @param itemId 订单详情ID
     * @return 结果
     */
    public int deleteFsStoreOrderItemById(Long itemId);

    List<FsStoreOrderItemVO> selectFsStoreOrderItemListByOrderId(Long ordreId);

    List<FsStoreOrderItemVO> selectFsStoreOrderItemListAndProductByOrderId(Long orderId);

    List<FsStoreOrderItemExportVO> selectFsStoreOrderItemListExportVO(FsStoreOrderParam fsStoreOrder);

    Long countFsStoreOrderItemListExportVO(FsStoreOrderParam fsStoreOrder);

    int updateFsStoreOrderCode(Long orderId, String orderCode);

    List<FsStoreOrderItemListDVO> selectFsStoreOrderItemListDVOByOrderId(Long orderId);
}
